==> task-v3.45.5.tar.gz: task-3.45.5/website/src/blog/index.md <==
---
title: Blog
description: Latest news and updates from the Task team
---

<BlogPost
title="Announcing Built-in Core Utilities for Windows"
url="/blog/windows-core-utils"
date="2025-09-15"
author="andreynering"
description="When I started Task back in 2017, one of my biggest goals was to build a task runner that would work well on all major platforms, including Windows. At the time, I was using Windows as my main platform, and it caught my attention how much of a pain it was to get a working version of Make on Windows, for example."
:tags="['windows', 'core-utils']"
/>

<BlogPost
title="Any Variables"
url="/blog/any-variables"
date="2024-05-09"
author="pd93"
description="Task has always had variables, but even though you were able to define them using different YAML types, they would always be converted to strings by Task. This limited users to string manipulation and encouraged messy workarounds for simple problems. Starting from v3.37.0, this is no longer the case! Task now supports most variable types, including booleans, integers, floats and arrays!"
:tags="['experiments', 'variables']"
/>

<BlogPost
title="Introducing Experiments"
url="/blog/task-in-2023"
date="2023-09-02"
author="pd93"
description="A look at where Task is, where it's going and how we're going to get there. Lately, Task has been growing extremely quickly and I've found myself thinking a lot about the future of the project and how we continue to evolve and grow. I'm not much of a writer, but I think one of the things we could do better is to communicate these kinds of thoughts to the community."
:tags="['roadmap', 'experiments', 'community']"
/>

==> task-v3.48.0.tar.gz: task-3.48.0/website/src/blog/index.md <==
---
title: Blog
description: Latest news and updates from the Task team
---

<BlogPost
title="New `if:` Control and Variable Prompt"
url="/blog/if-and-variable-prompt"
date="2026-01-24"
author="vmaerten"
description="The v3.47.0 release is here, and it brings two exciting new features to Task. Let's take a closer look at them!"
:tags="['new-features', 'variables']"
/>

<BlogPost
title="Announcing Built-in Core Utilities for Windows"
url="/blog/windows-core-utils"
date="2025-09-15"
author="andreynering"
description="When I started Task back in 2017, one of my biggest goals was to build a task runner that would work well on all major platforms, including Windows. At the time, I was using Windows as my main platform, and it caught my attention how much of a pain it was to get a working version of Make on Windows, for example."
:tags="['windows', 'core-utils']"
/>

<BlogPost
title="Any Variables"
url="/blog/any-variables"
date="2024-05-09"
author="pd93"
description="Task has always had variables, but even though you were able to define them using different YAML types, they would always be converted to strings by Task. This limited users to string manipulation and encouraged messy workarounds for simple problems. Starting from v3.37.0, this is no longer the case! Task now supports most variable types, including booleans, integers, floats and arrays!"
:tags="['experiments', 'variables']"
/>

<BlogPost
title="Introducing Experiments"
url="/blog/task-in-2023"
date="2023-09-02"
author="pd93"
description="A look at where Task is, where it's going and how we're going to get there. Lately, Task has been growing extremely quickly and I've found myself thinking a lot about the future of the project and how we continue to evolve and grow. I'm not much of a writer, but I think one of the things we could do better is to communicate these kinds of thoughts to the community."
:tags="['roadmap', 'experiments', 'community']"
/>
